@@ -63,6 +63,8 @@ const (
 	CMD_PRINT_ZSH_COMPLETION = "zsh-completion"
 	//nolint
 	CMD_PRINT_BASH_COMPLETION = "bash-completion"
+	//nolint
+	CMD_PRINT_FISH_COMPLETION = "fish-completion"
 
 	// filter: P1 P2 etc
 	PRIORITY_CRITICAL = "P0"
@@ -173,6 +175,7 @@ var ALL_CMDS = []string{
 	CMD_SHOW_UNORGANISED,
 	CMD_COMPLETIONS,
 	CMD_PRINT_BASH_COMPLETION,
+	CMD_PRINT_FISH_COMPLETION,
 	CMD_PRINT_ZSH_COMPLETION,
 	CMD_HELP,
 	CMD_VERSION,
